# <img src="/assets/purple-grape-vine.svg " width="128"> vino

a template for deep learning research projects



### Features

- [x] grid search
- [ ] class-level args
- [x] callbacks
- [ ] logging
    - [x] Comet ML
- [ ] hyperparameter optimization with Ray
- [x] standard formatting (autodocstring + black)
- [ ] tests

